@@ -144,6 +144,23 @@ An example of using options to control the results you get back:
 
 =cut
 
+=item C<offset> number
+
+C<Offset> says to skip that many rows before beginning to return rows (postgresql).
+
+
+Example:
+
+    # Get the name & phone number of the 10 highest-paid men starting from 11th:
+    database->quick_select(
+        'employees', 
+        { gender => 'male' },
+        { order_by => 'salary', offset => 10, limit => 10, columns => [qw(name phone)] }
+    );
+
+
+=cut
+
 sub quick_select {
     my ($self, $table_name, $where, $opts) = @_;
 
@@ -311,13 +328,13 @@ sub _quick_query {
     }
 
     # Add an ORDER BY clause, if we want to:
-    if (exists $opts->{order_by}) {
+    if (exists $opts->{order_by} and defined $opts->{order_by}) {
         $sql .= ' ' . $self->_build_order_by_clause($opts->{order_by});
     }
 
 
     # Add a LIMIT clause if we want to:
-    if (exists $opts->{limit}) {
+    if (exists $opts->{limit} and defined $opts->{limit}) {
         my $limit = $opts->{limit};
         $limit =~ s/\s+//g;
         # Check the limit clause is sane - just a number, or two numbers with a
@@ -333,6 +350,16 @@ sub _quick_query {
         # more than that
         $sql .= " LIMIT 1";
     }
+    
+	if (exists $opts->{offset} and defined $opts->{offset}) {
+        my $offset = $opts->{offset};
+        $offset =~ s/\s+//g;
+		if ($offset =~ /^\d+$/) {
+			$sql .= " OFFSET $offset";
+		} else {
+            die "Invalid OFFSET param $opts->{offset} !";
+		}
+	}
 
     # Dancer::Plugin::Database will have looked at the log_queries setting and
     # stashed it away for us to see:
@@ -514,7 +541,7 @@ Currently recognized operators are:
 ... same as C<WHERE foo LIKE '%bar%'>
 
 =item 'gt' / 'ge'
- 
+
  'greater than' or 'greater or equal to'
   
  { foo => { 'ge' => '42' } } 
@@ -528,7 +555,7 @@ Currently recognized operators are:
  { foo => { 'lt' => '42' } } 
 
 ... same as C<WHERE foo E<lt> '42'>
- 
+
 =item 'eq' / 'ne' / 'is'
 
  'equal' or 'not equal' or 'is'
